"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable react/prop-types */
var react_1 = __importStar(require("react"));
var context = react_1.createContext({
    stack: [],
    add: function () { },
    remove: function () { },
});
var Provider = context.Provider;
/**
 * This component is used to help with handling nested dialogs by:
 * - preventing all dialogs to be closed when the escape key is pressed
 * - hiding the overlays for dialogs that are not the top-most focus
 *
 * This should be added to the root of your app if you would like to enable this feature.
 */
exports.NestedDialogContextProvider = function (_a) {
    var children = _a.children;
    var _b = react_1.useState([]), stack = _b[0], setStack = _b[1];
    var add = react_1.useCallback(function (dialogId) {
        setStack(function (prevStack) {
            if (process.env.NODE_ENV !== "production" &&
                prevStack.includes(dialogId)) {
                /* eslint-disable no-console */
                console.warn("Tried to add a duplicate dialog id to the `NestedDialogContext`.");
                console.warn("This means that you have two dialogs with the same id: `" + dialogId + "`.");
                console.warn("This should be fixed before moving to production since this will break accessibility and is technically invalid.");
            }
            return prevStack.concat(dialogId);
        });
    }, []);
    var remove = react_1.useCallback(function (dialogId) {
        setStack(function (prevStack) { return prevStack.filter(function (id) { return id !== dialogId; }); });
    }, []);
    var value = react_1.useMemo(function () { return ({ stack: stack, add: add, remove: remove }); }, [add, remove, stack]);
    return react_1.default.createElement(Provider, { value: value }, children);
};
/**
 * Gets the current nested dialog context. This shouldn't really be used externally
 * and is a private context hook.
 *
 * @private
 */
function useNestedDialogContext() {
    return react_1.useContext(context);
}
exports.useNestedDialogContext = useNestedDialogContext;
//# sourceMappingURL=NestedDialogContext.js.map